@@ -1,24 +1,40 @@
 #!/usr/bin/python3
 
+# /usr/share/lintian/data/fields/obsolete-packages
+
 import glob
 import os
 import subprocess
 
+import apt
 import distro_info
 
 STABLE = distro_info.DebianDistroInfo().stable()
 
 testing = set()
-proc = subprocess.Popen(['apt-cache', 'pkgnames'],
-                        universal_newlines=True,
-                        stdout=subprocess.PIPE)
-for line in proc.stdout:
-    testing.add(line.rstrip())
+c = apt.Cache()
+for p in c.keys():
+    o = c[p]
+    if o.candidate:
+        d = o.candidate.record['Description'].lower()
+        if 'transitional' in d or 'dummy' in d:
+            pass
+        else:
+            testing.add(o.shortname)
+testing.add('usr-is-merged')
 
 # Add RaspBian
 testing.add('raspberrypi-bootloader')
 testing.add('libraspberrypi0')
 
+# Add BeagleBone
+testing.add('bb-customizations')
+testing.add('bb-node-red-installer')
+testing.add('c9-core-installer')
+testing.add('doc-beaglebone-getting-started')
+testing.add('librobotcontrol')
+testing.add('ti-pru-cgt-installer')
+
 # Add Hurd
 testing.add('hurd')
 testing.add('libc0.3')
@@ -30,6 +46,9 @@ testing.add('kali-menu')
 testing.add('kali-themes')
 testing.add('kali-themes-common')
 testing.add('kali-undercover')
+testing.add('king-phisher')
+testing.add('webshells')
+testing.add('wordlists')
 
 # Google repository
 testing.add('google-earth-stable')
